env_unlock: Unlock an environment

View source: R/env.R

env_unlockR Documentation

Unlock an environment

Description

[Defunct]. This function is now defunct because recent versions of R no longer make it possible to unlock an environment.

Usage

env_unlock(env)

Arguments

env

An environment.

Value

Whether the environment has been unlocked.


rlang documentation built on April 6, 2026, 5:07 p.m.