f_rhs extracts the right-hand side, f_lhs extracts the left-hand
side, and f_env extracts the environment in which the formula was defined.
All functions throw an error if f is not a formula.
Usage
f_rhs(f)
f_rhs(x) <- value
f_lhs(f)
f_lhs(x) <- value
f_env(f)
f_env(x) <- value
Value
f_rhs and f_lhs return language objects (i.e. atomic
vectors of length 1, a name, or a call). f_env returns an
environment.