View source: R/type-check-tabular.R
| check_data_frame | R Documentation |
Checks that an argument is a data frame, producing a friendly error message on failure.
check_data_frame(
x,
...,
allow_null = FALSE,
arg = caller_arg(x),
call = caller_env()
)
x |
The argument to check. |
... |
Additional arguments passed to |
allow_null |
Whether |
arg |
An argument name as a string. This argument will be mentioned in error messages as the input that is at the origin of a problem. |
call |
The execution environment of a currently
running function, e.g. |
NULL invisibly if the check passes, throws an error otherwise.
Other input checkers:
check_type_number,
check_type_scalar,
stop_input_type()
check_data_frame(mtcars)
try(check_data_frame(1:5))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.