These functions check that an argument is of the expected scalar type and produce friendly error messages otherwise.
Usage
check_bool(
x,
...,
allow_na = FALSE,
allow_null = FALSE,
arg = caller_arg(x),
call = caller_env()
)
check_string(
x,
...,
allow_empty = TRUE,
allow_na = FALSE,
allow_null = FALSE,
arg = caller_arg(x),
call = caller_env()
)
check_name(
x,
...,
allow_null = FALSE,
arg = caller_arg(x),
call = caller_env()
)Arguments
- x
The argument to check.
- ...
Additional arguments passed to
abort().- allow_na
Whether
NAvalues are allowed.- allow_null
Whether
NULLis allowed.- arg
An argument name as a string. This argument will be mentioned in error messages as the input that is at the origin of a problem.
- call
The execution environment of a currently running function, e.g.
caller_env(). The function will be mentioned in error messages as the source of the error. See thecallargument ofabort()for more information.- allow_empty
Whether the empty string
""is allowed (check_string()only).
See also
Other input checkers:
check_data_frame(),
check_type_number,
stop_input_type()