NULL invisibly if the check passes, throws an error otherwise.
Arguments
x
The argument to check.
...
Additional arguments passed to abort().
allow_na
Whether NA values are allowed.
allow_null
Whether NULL is allowed.
arg
An argument name as a string. This argument
will be mentioned in error messages as the input that is at the
origin of a problem.
call
The execution environment of a currently
running function, e.g. caller_env(). The function will be
mentioned in error messages as the source of the error. See the
call argument of abort() for more information.
allow_empty
Whether the empty string "" is allowed
(check_string() only).
See Also
Other input checkers:
check_data_frame(),
check_type_number,
stop_input_type()